@@ -273,7 +273,7 @@ class EducPlan(Base):
 
 class EducPlanPos(Base):
     """
-    Модель "Позиция учебного плана"
+    Позиция учебного плана
     """
     __tablename__ = 'univer_educ_plan_pos'
 
@@ -285,7 +285,7 @@ class EducPlanPos(Base):
         'univer_educ_plan.educ_plan_id'))
     educ_plan = relationship('EducPlan')
 
-    # Код дисциплины
+    # Код по РУП
     code = Column('rup_ru', String(50))
 
     # Дисциплина
@@ -297,16 +297,19 @@ class EducPlanPos(Base):
         'univer_controll_type.controll_type_id'))
     controll_type = relationship('ControllType')
 
-    # Кредит
+    # Количество кредитов
     credit = Column('educ_plan_pos_credit', Integer)
 
-    # Семестр
+    # Семестр, к котороу привязана позиция учебного плана
     semester = Column('educ_plan_pos_semestr', Integer)
 
     # Цикл
     cycle_id = Column(ForeignKey('univer_cycles.cycle_id'))
     cycle = relationship('Cycle')
 
+    # Количество часов
+    hours = Column('educ_plan_pos_hours', Integer)
+
     # Статус
     status = Column(Integer)
 
@@ -340,25 +343,43 @@ class Cycle(Base):
 
 class Attendance(Base):
     """
-    Модель "Журнал посещаемости"
+    Журнал посещений и успеваемости
     """
-
     __tablename__ = 'univer_attendance'
 
+    # Дата
     date = Column('att_date', Date, primary_key=True)
+
+    # Оценка/балл
     grade = Column('ball', Float)
+
+    # Был на занятии
     was = Column(Boolean)
+
+    @validates('was')
+    def validate_was(self, key, value):
+        """
+        Поддерживает два значения:
+        0 - не был
+        1 - был
+        """
+        assert value in [0, 1]
+        return value
+
+    # Студент
     student_id = Column(ForeignKey(
         'univer_students.students_id'), primary_key=True)
     student = relationship('Student')
+
+    # Группа студентов
     group_id = Column(ForeignKey('univer_group.group_id'), primary_key=True)
     group = relationship('Group')
 
     def __repr__(self):
-        return '<Attendance {}: {} балл ({})>'.format(self.student, self.grade, self.date)
+        return f'<Attendance {self.student}: {self.grade} ({self.date})>'
 
     def __str__(self):
-        return '{}: {} балл ({})'.format(self.student, self.grade, self.date)
+        return f'{self.student}: {self.grade} балл ({self.date})'
 
 
 class EducLang(Base):
@@ -392,24 +413,35 @@ class EducLang(Base):
 
 class Group(Base):
     """
-    Модель "Группа"
-    Статус: Выполняется
+    Группа студентов
     """
-
     __tablename__ = 'univer_group'
 
+    # Идентификатор
     id = Column('group_id', Integer, primary_key=True)
+
+    # Позиция учебного плана
     educ_plan_pos_id = Column('educ_plan_pos_id', ForeignKey(
         'univer_educ_plan_pos.educ_plan_pos_id'))
     educ_plan_pos = relationship('EducPlanPos', backref='groups')
+
+    # Преподаватель
     teacher_id = Column('teacher_id', ForeignKey('univer_teacher.teacher_id'))
     teacher = relationship('Teacher')
+
+    # Академический год
     year = Column('group_year', Float)
+
+    # Академический семестр
     semester = Column('group_semestr', Integer)
+
     acpos_module = Column('acpos_module', Integer)
+
     educ_type_id = Column('educ_type_id', ForeignKey(
         'univer_educ_type.educ_type_id'))
     educ_type = relationship('EducType')
+
+    # Языковый отдел
     lang_division_id = Column('lang_division_id', ForeignKey(
         'univer_lang_division.lang_division_id'))
     lang_division = relationship('LangDivision')
@@ -422,10 +454,10 @@ class Group(Base):
     retake_semester = Column('group_retake_semestr', Integer)
 
     def __repr__(self):
-        return '<Group {} (id={} educ_plan_pos_id={} teacher_id={})>'.format(self, self.id, self.educ_plan_pos_id, self.teacher_id)
+        return f'<Group {self} (id={self.id} educ_plan_pos_id={self.educ_plan_pos_id} teacher_id={self.teacher_id})>'
 
     def __str__(self):
-        return '{} ({} год)'.format(self.educ_plan_pos.educ_plan.speciality, self.educ_plan_pos.educ_plan.year)
+        return f'{self.educ_plan_pos.educ_plan.speciality} ({self.educ_plan_pos.year} год)'
 
 
 class GroupStudent(Base):
