@@ -1,5 +1,5 @@
 from sqlalchemy import Column, Integer, String, Float, Boolean, ForeignKey, Date, DateTime
-from sqlalchemy.orm import relationship, backref
+from sqlalchemy.orm import relationship, backref, validates
 
 from univer_db.orm import get_base
 
@@ -39,10 +39,8 @@ class User(Base):
 
 class Student(Base):
     """
-    Модель "Студенты"
-    Статус: Выполняется
+    Студенты
     """
-
     __tablename__ = 'univer_students'
     __table_args__ = {
         'implicit_returning': False
@@ -51,56 +49,135 @@ class Student(Base):
     # Идентификатор
     id = Column('students_id', Integer, primary_key=True)
 
+    # Статус
+    status = Column('status', Integer)
+
+    @validates('status')
+    def validate_status(self, key, value):
+        """
+        Значением status могут быть следующие значения:
+        - 1 (Активный)
+        - 2 (Архивный)
+        - 10 (Абитуриент)
+        """
+        assert value in [1, 2, 10]
+        return value
+
     # Пользователь
     user_id = Column('user_id', ForeignKey('univer_users.user_id'))
     user = relationship('User')
 
-    # Статус
-    status = Column('status', Integer)
-
-    # Дата регистрации
-    reg_date = Column('student_reg_date', DateTime)
-
     # Ступень обучения
     stage_id = Column(ForeignKey('univer_stage.stage_id'))
     stage = relationship('Stage')
 
+    # Факультет
+    faculty_id = Column(ForeignKey('univer_faculty.faculty_id'))
+    faculty = relationship('Faculty')
+
+    # Специальность/ОП
+    speciality_id = Column(ForeignKey('univer_speciality.speciality_id'))
+    speciality = relationship('Speciality')
+
+    # Страна
+    country_id = Column(ForeignKey('univer_country.country_id'))
+    country = relationship('Country')
+
+    # Дата регистрации
+    reg_date = Column('student_reg_date', DateTime)
+
     # Уровень обучения
     edu_level_id = Column('edu_levels_id', ForeignKey(
         'univer_edu_levels.edu_level_id'))
     edu_level = relationship('EduLevel')
 
-    # Форма обучения
-    education_form_id = Column(ForeignKey(
-        'univer_education_form.education_form_id'))
-    education_form = relationship('EducationForm')
+    # Национальность
+    nationality_id = Column(ForeignKey('univer_nationality.nationality_id'))
+    nationality = relationship('Nationality')
 
-    # Тип поступления
-    enrollment_type_id = Column(ForeignKey(
-        'univer_enrollment_type.enrollment_type_id'))
-    enrollment_type = relationship('EnrollmentType')
+    # Гражданство
+    citizenship_id = Column(ForeignKey('univer_citizenship_1c.citizenship_id'))
+    citizenship = relationship('Citizenship')
 
     # Тип оплаты
     payment_form_id = Column('payment_forms_id', ForeignKey(
         'univer_payment_forms.payment_form_id'))
     payment_form = relationship('PaymentForm')
 
-    country_id = Column(ForeignKey('univer_country.country_id'))
-    country = relationship('Country')
+    # Форма обучения
+    education_form_id = Column(ForeignKey(
+        'univer_education_form.education_form_id'))
+    education_form = relationship('EducationForm')
 
-    # Пол
-    sex = Column('students_sex', Integer)
+    # Неизвестное поле
+    settlement_status_id = Column(ForeignKey(
+        'univer_settlement_status.settlement_status_id'))
+    settlement_status = relationship('SettlementStatus')
 
-    marital_status = Column('students_marital_status', Integer)
+    # Иностранный язык
+    foreign_language_id = Column(ForeignKey(
+        'univer_foreign_language.foreign_language_id'))
+    foreign_language = relationship('ForeignLanguage')
 
-    # Дата рождения
-    birth_date = Column('students_birth_date', DateTime)
+    # Причина поступления
+    admission_reason_id = Column(ForeignKey(
+        'univer_admission_reason.admission_reason_id'))
+    admission_reason = relationship('AdmissionReason')
+
+    # Регион
+    region_id = Column(ForeignKey('univer_region.region_id'))
+    region = relationship('Region')
+
+    # Тип поступления
+    enrollment_type_id = Column(ForeignKey(
+        'univer_enrollment_type.enrollment_type_id'))
+    enrollment_type = relationship('EnrollmentType')
+
+    # Район
+    district_id = Column(ForeignKey('univer_district.district_id'))
+    district = relationship('District')
 
     # ФИО студента
     last_name = Column('students_sname', String(100))
     first_name = Column('students_name', String(100))
     middle_name = Column('students_father_name', String(100))
 
+    # Дата рождения
+    birth_date = Column('students_birth_date', DateTime)
+
+    # Электронная почта
+    email = Column('students_email', String(25))
+
+    # Пол
+    sex = Column('students_sex', Integer)
+
+    @validates('sex')
+    def validate_sex(self, key, value):
+        """
+        Значением sex могут быть следующие значения:
+        - 1 (Мужчина)
+        - 0 (Женщина)
+        """
+        assert value in [0, 1]
+        return value
+
+    marital_status = Column('students_marital_status', Integer)
+
+    @validates('marital_status')
+    def validate_marital_status(self, key, value):
+        """
+        Значением marital_status могут быть следующие значения:
+        - 0 (Не женат/Не замужена)
+        - 1 (Женат/замужена)
+        """
+        assert value in [0, 1]
+        return value
+
+    # Статус студента
+    edu_status_id = Column('student_edu_status_id', ForeignKey(
+        'univer_student_edu_statuses.student_edu_status_id'))
+    edu_status = relationship('EduStatus')
+
     # ФИО студента в дательном падеже (На русском языке)
     dative_last_name_ru = Column('students_dative_sname_ru', String(100))
     dative_first_name_ru = Column('students_dative_name_ru', String(100))
@@ -123,9 +200,6 @@ class Student(Base):
     last_name_translit = Column('students_sname_intern', String(100))
     first_name_translit = Column('students_name_intern', String(100))
 
-    # Электронная почта
-    email = Column('students_email', String(25))
-
     # Курс
     course = Column('students_curce_number', Integer)
 
@@ -148,22 +222,6 @@ class Student(Base):
         'univer_graduate_info.graduate_info_id'))
     graduate_info = relationship('GraduateInfo')
 
-    # Факультет
-    faculty_id = Column(ForeignKey('univer_faculty.faculty_id'))
-    faculty = relationship('Faculty')
-
-    # ОП
-    speciality_id = Column(ForeignKey('univer_speciality.speciality_id'))
-    speciality = relationship('Speciality')
-
-    # Гражданство
-    citizenship_id = Column(ForeignKey('univer_citizenship_1c.citizenship_id'))
-    citizenship = relationship('Citizenship')
-
-    # Национальность
-    nationality_id = Column(ForeignKey('univer_nationality.nationality_id'))
-    nationality = relationship('Nationality')
-
     # Год начала действия учебного плана
     educ_plan_adm_year = Column(Integer)
 
@@ -228,10 +286,12 @@ class Student(Base):
         return ' '.join(filter(None, [self.dative_last_name_en, self.dative_first_name_en, self.dative_middle_name_en]))
 
     def __repr__(self):
-        return '<Student {} (id={} user={} status={})>'.format(self, self.id, self.user_id, self.status)
+        return f'<Student {self} (id={self.id} user={self.user_id} status={self.status})>'
 
     def __str__(self):
-        return ' '.join(filter(None, [self.last_name, self.first_name, self.middle_name]))
+        full_name = ' '.join(
+            filter(None, [self.last_name, self.first_name, self.middle_name]))
+        return f'{full_name}'
 
 
 class Personnel(Base):
